@@ -456,17 +456,15 @@ class IQ_Option:
 
     def get_candles(self, ACTIVES, interval, count, endtime):
         self.api.candles.candles_data = None
-        while True:
-            try:
-                self.api.getcandles(
-                    OP_code.ACTIVES[ACTIVES], interval, count, endtime)
-                while self.check_connect and self.api.candles.candles_data == None:
-                    pass
+        try:
+            self.api.getcandles(
+                OP_code.ACTIVES[ACTIVES], interval, count, endtime)
+            while self.check_connect:
                 if self.api.candles.candles_data != None:
                     break
-            except:
-                logging.error('**error** get_candles need reconnect')
-                raise ConnectionError
+        except:
+            logging.error('**error** get_candles need reconnect')
+            raise ConnectionError
 
         return self.api.candles.candles_data
 
